@@ -1,21 +1,16 @@
 from taupy.basic.utilities import satisfiability_count, dict_to_prop
-from sympy.logic import (And, Implies, Not)
+from sympy.logic import And
 from fractions import Fraction
 
 def doj(pos, debate=None, conditional=None):
     """
     Returns the degree of justification for the position in ``pos`` relative
-    to a ``debate``. If ``debate`` is `None`, the debate stored in the
-    Position object is used. 
+    to a ``debate``, as defined in [Betz2012]_. If ``debate`` is `None`, the 
+    debate stored in the Position object is used. 
     
     The *conditional* doj is returned if ``conditional`` is given another
     position of the same debate. When ``conditional`` is set, ``debate``
-    must be `None`.        
-    
-    References
-    ----------
-    Betz, Gregor. 2012. On degrees of justification. Erkenntnis 77.
-    pp. 237--272. DOI: 10/bkng95
+    must be `None`.
     """
     
     if debate is None: 
